from .Client import Client
from .utils import exceptions, helpers, headers

from os import system as s
from colored import fore

__title__ = 'nz-ua.py'
__author__ = 'Xsarz'
__license__ = 'MIT'
__copyright__ = 'Copyright 2023 Xsarz'
__version__ = '1.0'
__newest__ = __version__


if __version__ != __newest__:
	s('cls || clear')
	print(fore.ORANGE_1, f'{__title__} made by {__author__}\nPlease update the library. Your version: {__version__}  A new version:{__newest__}', fore.WHITE)


from setuptools import setup, find_packages



long_description = 'With the help of this library, you can embed api from the nz-ua application into your projects.'
link = 'https://github.com/xXxCLOTIxXx/nz-ua.py/archive/refs/heads/main.zip'
ver = '1.0'

setup(
	name = "nz-ua.py",
	version = ver,
	url = "https://github.com/xXxCLOTIxXx/nz-ua.py",
	download_url = link,
	license = "MIT",
	author = "Xsarz",
	author_email = "xsarzy@gmail.com",
	description = "Library for working with the nz-ua application.",
	long_description = long_description,
	keywords = [
		"nz",
		"nz.py",
		"nz-ua",
		"nz-ua.py",
		"async"
		"api",
		"python",
		"python3",
		"python3.x",
		"xsarz",
		"official"
	],
	install_requires = [
		"colored",
		"aiohttp"
	],
	packages = find_packages()
)



from json import dumps, loads
from .utils import exceptions, helpers, objects
from .utils.headers import Headers

class Client(Headers):
	def __init__(self, profile: objects.Student = None):
		self.api = 'https://api-mobile.nz.ua/v1'
		self.student = profile if profile else objects.Student()
		
		Headers.__init__(self)


	async def login(self, username: str, password: str):

		data = dumps({
			"username":username,
			"password":password
		})

		response = objects.Student(await helpers.post(f"{self.api}/user/login", headers=self.headers(data=data), data=data))
		self.student = response
		return self.student

	async def logout(self):
		self.student = objects.Student()
		return self.student


	async def get_schedule(self, start_date: str = "2023-02-13", end_date: str = "2023-02-19"):

		data = dumps({
			"start_date": start_date,
			"end_date": end_date,
			"student_id": self.student.student_id
		})

		response = objects.Schedule(await helpers.post(f"{self.api}/schedule/diary", headers=self.headers(data=data, access_token=self.student.access_token), data=data))
		return response


	async def get_hometask(self, hometask_id: int):
		data = dumps({
			"distance_hometask_id": hometask_id,
			"student_id": self.student.student_id
		})

		response = objects.Hometask(await helpers.post(f"{self.api}/schedule/distance-hometask", headers=self.headers(data=data, access_token=self.student.access_token), data=data))
		return response

	async def get_timetable(self, start_date: str = "2023-02-13", end_date: str = "2023-02-19"):
		#TODO: objects for this 
		data = dumps({
			"start_date": start_date,
			"end_date": end_date,
			"student_id": self.student.student_id
		})

		response = await helpers.post(f"{self.api}/schedule/diary", headers=self.headers(data=data, access_token=self.student.access_token), data=data)
		return response

	async def get_student_performance(self, start_date: str = "2023-02-13", end_date: str = "2023-02-19"):
		#TODO: objects for this 

		data = dumps({
			"start_date": start_date,
			"end_date": end_date,
			"student_id": self.student.student_id
		})

		response = await helpers.post(f"{self.api}/schedule/student-performance", headers=self.headers(data=data, access_token=self.student.access_token), data=data)
		return response


	async def get_subject_performance(self, subject_id: int, start_date: str = "2023-02-13", end_date: str = "2023-02-19"):
		#TODO: objects for this 

		data = dumps({
			"start_date": start_date,
			"end_date": end_date,
			"student_id": self.student.student_id,
			"subject_id": subject_id
		})

		response = await helpers.post(f"{self.api}/schedule/subject-grades", headers=self.headers(data=data, access_token=self.student.access_token), data=data)
		return response